==> fvtt-mournblade-0.0.5.tar.gz: fvtt-mournblade/modules/mournblade-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { MournbladeUtility } from "./mournblade-utility.js";
import { MournbladeRollDialog } from "./mournblade-roll-dialog.js";

/* -------------------------------------------- */
export class MournbladeActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-mournblade", "sheet", "actor"],
      template: "systems/fvtt-mournblade/templates/actor-sheet.html",
      width: 640,
      height: 720,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "stats" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: false
    });
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = MournbladeUtility.data(this.object);
    
    let actorData = duplicate(MournbladeUtility.templateData(this.object));

    let formData = {
      title: this.title,
      id: objectData.id,
      type: objectData.type,
      img: objectData.img,
      name: objectData.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      data: actorData,
      effects: this.object.effects.map(e => foundry.utils.deepClone(e.data)),
      limited: this.object.limited,
      skills: duplicate(this.actor.getSkills()),
      weapons: duplicate(this.actor.getWeapons()),
      armors: duplicate(this.actor.getArmors()),
      //equipments: duplicate(this.actor.getEquipments()),
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM
    }
    this.formData = formData;

    console.log("PC : ", formData, this.object);
    return formData;
  }

  
  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    html.bind("keydown", function(e) { // Ignore Enter in actores sheet
      if (e.keyCode === 13) return false;
    });  

    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId )
      item.sheet.render(true)
    });
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      MournbladeUtility.confirmDelete(this, li);
    });
    
    html.find('.spec-group-activate').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let itemId = li.data("item-id");
      this.actor.specPowerActivate( itemId)
    });      
    html.find('.spec-group-deactivate').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let itemId = li.data("item-id");
      this.actor.specPowerDeactivate( itemId)
    });      

    html.find('.equip-activate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipActivate( itemId)
    });      
    html.find('.equip-deactivate').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      this.actor.equipDeactivate( itemId)
    });      

    html.find('.effect-used').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let itemId = li.data("item-id");
      this.actor.perkEffectUsed( itemId)
    });      

    html.find('.perk-status').change(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let itemId = li.data("item-id");
      this.actor.updatePerkStatus( itemId, ev.currentTarget.value)
    });
    html.find('.power-cost-spent').change(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let itemId = li.data("item-id");
      this.actor.updatePowerSpentCost( itemId, ev.currentTarget.value)
    });
    html.find('.perk-used').change(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      let index = Number($(ev.currentTarget).data("use-index") )
      this.actor.updatePerkUsed( itemId, index, ev.currentTarget.checked )
    });
    
    html.find('.subactor-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      let actor = game.actors.get( actorId );
      actor.sheet.render(true);
    });
    
    html.find('.subactor-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      let actorId = li.data("actor-id");
      this.actor.delSubActor(actorId);
    });
    
    html.find('.quantity-minus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), -1 );
    } );
    html.find('.quantity-plus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), +1 );
    } );

    html.find('.unarmed-attack').click((event) => {
      this.actor.rollUnarmedAttack();
    });
    html.find('.generic-pool-roll').click((event) => {      
      this.openGenericRoll()
    } );
    html.find('.attack-melee').click((event) => {
      this.actor.rollPool( 'com');
    });
    html.find('.attack-ranged').click((event) => {
      this.actor.rollPool( 'agi');
    });
    html.find('.defense-roll').click((event) => {
      this.actor.rollPool( 'def', true);
    });
    html.find('.damage-melee').click((event) => {
      this.actor.rollPool( 'str');
    });
    html.find('.damage-ranged').click((event) => {
      this.actor.rollPool( 'per');
    });
    html.find('.damage-resistance').click((event) => {
      this.actor.rollPool( 'phy');
    });
            
    html.find('.roll-stat').click((event) => {
      const statId = $(event.currentTarget).data("stat-key");
      this.actor.rollStat(statId);
    });
    html.find('.roll-mr').click((event) => {
      this.actor.rollMR();
    });
    
    html.find('.roll-spec').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const specId = li.data("item-id");
      this.actor.rollSpec(specId);
    });
    html.find('.power-roll').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const powerId = li.data("item-id");
      this.actor.rollPower(powerId);
    });        
    html.find('.weapon-roll').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const weaponId = li.data("item-id");
      this.actor.rollWeapon(weaponId);
    });
    html.find('.armor-roll').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const armorId = li.data("item-id");
      this.actor.rollArmor(armorId);
    });
    
    html.find('.weapon-damage-roll').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const weaponId = li.data("item-id");
      this.actor.rollWeapon(weaponId, true);
    });
    
    html.find('.weapon-damage').click((event) => {
      const li = $(event.currentTarget).parents(".item");
      const weapon = this.actor.getOwnedItem(li.data("item-id"));
      this.actor.rollDamage(weapon, 'damage');
    });
    
    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-link a').click((event) => {
      const itemId = $(event.currentTarget).data("item-id");
      const item = this.actor.getOwnedItem(itemId);
      item.sheet.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });
    html.find('.power-activate').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.activatePower( li.data("item-id") );
      this.render(true); 
    });
    
    html.find('.change-worstfear').change(ev => {
      this.actor.manageWorstFear( ev.currentTarget.checked )
    });
    html.find('.change-desires').change(ev => {
      this.actor.manageDesires( ev.currentTarget.checked )
    });

    html.find('.update-field').change(ev => {
      const fieldName = $(ev.currentTarget).data("field-name");
      let value = Number(ev.currentTarget.value);
      this.actor.update( { [`${fieldName}`]: value } );
    });    
    html.find('.perk-active').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.activatePerk( li.data("item-id") );
      this.render(true);      
    });

  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  async _onDropItem(event, dragData) {
    let item = await MournbladeUtility.searchItem( dragData)
    this.actor.preprocessItem( event, item, true )
    super._onDropItem(event, dragData)
  }

  /* -------------------------------------------- */
  /** @override */
  _updateObject(event, formData) {
    // Update the Actor
    return this.object.update(formData);
  }
}

==> fvtt-mournblade-10.0.0.tar.gz: fvtt-mournblade/modules/mournblade-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { MournbladeUtility } from "./mournblade-utility.js";
import { MournbladeRollDialog } from "./mournblade-roll-dialog.js";

/* -------------------------------------------- */
export class MournbladeActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-mournblade", "sheet", "actor"],
      template: "systems/fvtt-mournblade/templates/actor-sheet.html",
      width: 640,
      height: 720,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "stats" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: false
    });
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = duplicate(this.object)    
    let actorData = objectData 

    let formData = {
      title: this.title,
      id: objectData.id,
      type: objectData.type,
      img: objectData.img,
      name: objectData.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      data: actorData.system,
      effects: this.object.effects.map(e => foundry.utils.deepClone(e.data)),
      limited: this.object.limited,
      skills: this.actor.getSkills(),
      armes: duplicate(this.actor.getWeapons()),
      protections: duplicate(this.actor.getArmors()),
      dons: duplicate(this.actor.getDons()),
      alignement: this.actor.getAlignement(),
      tendances:duplicate(this.actor.getTendances()),
      runes:duplicate(this.actor.getRunes()),
      origine: duplicate(this.actor.getOrigine() || {}),
      heritage: duplicate(this.actor.getHeritage() || {}),
      metier: duplicate(this.actor.getMetier()  || {}),
      combat: this.actor.getCombatValues(),      
      equipements: duplicate(this.actor.getEquipments()),
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM
    }
    this.formData = formData;

    console.log("PC : ", formData, this.object);
    return formData;
  }

  
  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId )
      item.sheet.render(true)
    })      
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      MournbladeUtility.confirmDelete(this, li);
    })
    html.find('.edit-item-data').change(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId    = li.data("item-id")
      let itemType  = li.data("item-type")
      let itemField = $(ev.currentTarget).data("item-field")
      let dataType = $(ev.currentTarget).data("dtype")
      let value = ev.currentTarget.value
      this.actor.editItemField(itemId, itemType, itemField, dataType, value)
    })
    
    html.find('.quantity-minus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), -1 );
    } );
    html.find('.quantity-plus').click(event => {
      const li = $(event.currentTarget).parents(".item");
      this.actor.incDecQuantity( li.data("item-id"), +1 );
    } );

    html.find('.roll-attribut').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let attrKey = li.data("attr-key")
      this.actor.rollAttribut(attrKey)
    })
    html.find('.roll-competence').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let attrKey = $(event.currentTarget).data("attr-key")
      let compId  = li.data("item-id")
      this.actor.rollCompetence(attrKey, compId)
    })
    html.find('.roll-rune').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let runeId  = li.data("item-id")
      this.actor.rollRune(runeId)
    })
    html.find('.roll-arme-offensif').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let armeId  = li.data("item-id")
      this.actor.rollArmeOffensif(armeId)
    })
    html.find('.roll-arme-degats').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let armeId  = li.data("item-id")
      this.actor.rollArmeDegats(armeId)
    })
        
    
    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });

  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  /*async _onDropItem(event, dragData) {
    let item = await MournbladeUtility.searchItem( dragData)
    this.actor.preprocessItem( event, item, true )
    super._onDropItem(event, dragData)
  }*/

  /* -------------------------------------------- */
  /** @override */
  _updateObject(event, formData) {
    // Update the Actor
    return this.object.update(formData);
  }
}
